# Security Policy

| Version | Security Advisory | Reporting a Vulnerability                            |
|:------- |:----------------- |:---------------------------------------------------- |
| 0.1.x   | Local-only tool   | Report issues via GitHub security advisories / email |
